@@ -2,7 +2,7 @@ import sklearn.preprocessing
 import numpy as np
 
 
-def make_scalers(X, method="MinMaxScaler"):
+def make_scalers(X, method="MinMaxScaler", feature_range=(0, 1)):
     """This function takes an input array, X, and returns
     a list of sklearn scalers for each input feature/dimension.
 
@@ -17,6 +17,8 @@ def make_scalers(X, method="MinMaxScaler"):
         common choices are "MinMaxScaler" or "StandardScaler".
         But in theory any `sklearn.preprocessing` scaler method should work
          (default: {"MinMaxScaler"})
+        feature_range {tuple} -- (min, max), default=(0, 1)
+            Only applicable for method='MinMaxScaler'
 
     Returns:
         list -- a least of length M of sklearn.preprocessing.[METHOD].
@@ -29,7 +31,10 @@ def make_scalers(X, method="MinMaxScaler"):
 
     # make a scaler for each feature/dimension
     for i in range(M):
-        scaler_func = getattr(sklearn.preprocessing, method)()
+        if method == "MinMaxScaler":
+            scaler_func = sklearn.preprocessing.MinMaxScaler(feature_range=feature_range)
+        else:
+            scaler_func = getattr(sklearn.preprocessing, method)()
         scalers.append(scaler_func)
         scalers[i].fit(X[:, i].reshape(-1, 1))
 
