@@ -3,6 +3,8 @@ tools to explore effect of hyperparameters
 """
 
 import tensorflow as tf
+import pugna.activations
+
 
 def build_model(input_dim,
                 output_dim,
@@ -39,7 +41,8 @@ def build_model(input_dim,
     """
 
     allowed_activations = ['relu', 'leaky_relu',
-                           'prelu', 'elu', 'softplus', 'tanh', 'selu']
+                           'prelu', 'elu', 'softplus', 'tanh', 'selu',
+                           'srelu', 'srelu2', 'srelu3']
 
     if activation not in allowed_activations:
         raise ValueError(
@@ -76,6 +79,12 @@ def build_model(input_dim,
             elif activation == "selu":
                 model.add(tf.keras.layers.Activation(
                     tf.keras.activations.selu))
+            elif activation == "srelu":
+                model.add(pugna.activations.sReLU_Layer())
+            elif activation == "srelu2":
+                model.add(pugna.activations.sReLU_2_Layer())
+            elif activation == "srelu3":
+                model.add(pugna.activations.sReLU_3_Layer())
         if batch_norm:
             model.add(tf.keras.layers.BatchNormalization())
     model.add(tf.keras.layers.Dense(output_dim, activation='linear'))
