@@ -48,13 +48,14 @@ def save_model_h5(model, model_name):
     model.save(f'{model_name}.h5')
 
 
-def load_model_h5(filename):
+def load_model_h5(filename, custom_objects=None):
     """load h5 model
 
     Args:
         filename (str): h5 file containing saved keras model
+        custom_objects ([dict], optional): Dictionary to pass to tf.keras.models.load_model.
     """
-    return tf.keras.models.load_model(filename)
+    return tf.keras.models.load_model(filename, custom_objects=custom_objects)
 
 
 def save_model_checkpoint(model, model_name, num, zpad='04'):
@@ -65,13 +66,14 @@ def save_model_checkpoint(model, model_name, num, zpad='04'):
     model.save(f'{model_name}_checkpoint_' + format(num, zpad) + '.h5')
 
 
-def load_model_checkpoint(model_name, num, zpad='04'):
+def load_model_checkpoint(model_name, num, zpad='04', custom_objects=None):
     """
     name format: '{model_name}+checkpoint_0001.h5'
+    custom_objects ([dict], optional): Dictionary to pass to tf.keras.models.load_model.
     """
     # loading the model from the HDF5 file
     model = tf.keras.models.load_model(
-        f'{model_name}_checkpoint_' + format(num, zpad) + '.h5')
+        f'{model_name}_checkpoint_' + format(num, zpad) + '.h5', custom_objects=custom_objects)
     return model
 
 
@@ -101,3 +103,26 @@ def load_history(filename):
         history = pickle.load(pfile)
 
     return history
+
+def save_datetime(value, filename):
+    """saves the datetime to a pickle file
+
+    Args:
+        value (datetime):
+        filename (str): full path and name output pickle file
+    """
+    with open(filename, 'wb') as f:
+        pickle.dump(value, f)
+
+def load_datetime(filename):
+    """load the datetime from a pickle file
+
+    Args:
+        filename (str): full path and name output pickle file
+
+    Returns:
+        value (datetime): datetime
+    """
+    with open(filename, 'rb') as f:
+        value = pickle.load(f)
+    return value
